"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaConsumerServer = void 0;
const kafkajs_1 = require("kafkajs");
const stream_1 = require("stream");
class KafkaConsumerServer extends stream_1.EventEmitter {
    constructor(options = {}) {
        super();
        this.connection = null;
        this.loggers = options.logger;
        this.bindError();
    }
    bindError() {
        this.on('error', err => {
            this.loggers.error(err);
        });
    }
    async connect(options, consumerOptions) {
        this.connection = new kafkajs_1.Kafka(options).consumer(consumerOptions);
        this.connection.on('consumer.connect', () => {
            this.loggers.info('Kafka consumer connected!');
        });
        this.connection.on('consumer.disconnect', err => {
            if (err) {
                this.loggers.error('Kafka consumer disconnected', err);
            }
            else {
                this.loggers.info('Kafka consumer disconnected!');
            }
        });
    }
    async closeConnection() {
        try {
            if (this.connection) {
                await this.connection.disconnect();
            }
            this.loggers.debug('Kafka consumer connection close success');
        }
        catch (err) {
            this.loggers.error('Kafka consumer connection close error', err);
        }
        finally {
            this.connection = null;
        }
    }
    async close() {
        this.loggers.debug('Kafka consumer will be close');
        await this.closeConnection();
    }
}
exports.KafkaConsumerServer = KafkaConsumerServer;
//# sourceMappingURL=kafka.js.map